Django Media Explorer
=====================

Go to https://github.com/oxfamamerica/django-media-explorer for documentation.

Screen shots
------------

`Images <http://media.oxfamamerica.org.s3.amazonaws.com/images/github/dme-images.jpg>`_

`Add images <http://media.oxfamamerica.org.s3.amazonaws.com/images/github/dme-images-add.jpg>`_

`Videos <http://media.oxfamamerica.org.s3.amazonaws.com/images/github/dme-videos.jpg>`_

`Add video <http://media.oxfamamerica.org.s3.amazonaws.com/images/github/dme-videos-add.jpg>`_

`Gallery <http://media.oxfamamerica.org.s3.amazonaws.com/images/github/dme-gallery.jpg>`_

`Add gallery <http://media.oxfamamerica.org.s3.amazonaws.com/images/github/dme-gallery-add.jpg>`_

`Edit gallery <http://media.oxfamamerica.org.s3.amazonaws.com/images/github/dme-gallery-edit.jpg>`_
